@@ -5,7 +5,7 @@
 #'
 #' @param filepath string. Full path to the input curv file. Note: gzipped binary curv files are supported and gz binary format is assumed if the filepath ends with ".gz".
 #'
-#' @param format one of 'auto', 'asc', 'bin', or 'txt'. The format to assume. If set to 'auto' (the default), binary format will be used unless the filepath ends with '.asc' or '.txt'. The latter is just one float value per line in a text file.
+#' @param format one of 'auto', 'asc', 'bin', 'nii' or 'txt'. The format to assume. If set to 'auto' (the default), binary format will be used unless the filepath ends with '.asc' or '.txt'. The latter is just one float value per line in a text file.
 #'
 #' @return data vector of floats. The brain morphometry data, one value per vertex.
 #'
@@ -68,6 +68,51 @@ read.fs.morph.asc <- function(filepath) {
 }
 
 
+#' @title Read morphometry data from FreeSurfer NIFTI format files, determine NIFTI version automatically.
+#'
+#' @param filepath path to a file in FreeSurfer NIFTI v1 or v2 format, potentially with the FreeSurfer hack for v1. See \code{\link{read.nifti1.data}} and \code{\link{read.nifti2.data}} for details.
+#'
+#' @return numeric vector, the morphometry data
+#'
+#' @export
+read.fs.morph.nii <- function(filepath) {
+  nfv = nifti.file.version(filepath);
+  if(nfv == 1L) {
+    return(read.fs.morph.ni1(filepath));
+  } else if(nfv == 2L) {
+    return(read.fs.morph.ni2(filepath));
+  } else {
+    stop("File not in NIFTI v1 or v2 format.");
+  }
+}
+
+
+#' @title Read morphometry data from FreeSurfer NIFTI v1 format files.
+#'
+#' @param filepath path to a file in FreeSurfer NIFTI v1 format, potentially with the FreeSurfer hack. See \code{\link{read.nifti1.data}} for details.
+#'
+#' @return numeric vector, the morphometry data
+#'
+#' @note This function uses our internal NIFTI reader that supports NIFTI v1 files with the FreeSurfer hack. This function assumes that the data in a file is a 1D vector and flattens it accordingly. It is not suitable to load NIFTI files with arbitrary dimensions.
+#'
+#' @export
+read.fs.morph.ni1 <- function(filepath) {
+  return(as.double(read.nifti1.data(filepath)));
+}
+
+
+#' @title Read morphometry data from FreeSurfer NIFTI v2 format files.
+#'
+#' @param filepath path to a file in FreeSurfer NIFTI v2 format, potentially with the FreeSurfer hack. See \code{\link{read.nifti2.data}} for details.
+#'
+#' @return numeric vector, the morphometry data
+#'
+#' @export
+read.fs.morph.ni2 <- function(filepath) {
+  return(as.double(read.nifti2.data(filepath)));
+}
+
+
 #' @title Read morphometry data from plain text file
 #'
 #' @param filepath path to a file in plain text format. Such a file contains, on each line, a single float value. This very simply and limited *format* is used by the LGI tool by Lyu et al., and easy to generate in shell scripts.
@@ -128,8 +173,8 @@ fread3 <- function(filehandle) {
 #'
 #' @export
 read.fs.morph <- function(filepath, format='auto') {
-    if(! format %in% c("auto", "mgh", "mgz", "curv", "gii", "smp")) {
-        stop("Format must be one of 'auto', 'mgh', 'mgz', 'curv', 'smp', or 'gii'.");
+    if(! format %in% c("auto", "mgh", "mgz", "curv", "gii", "smp", 'nii', 'ni1', 'ni2')) {
+        stop("Format must be one of 'auto', 'mgh', 'mgz', 'curv', 'smp', 'gii, 'nii', 'ni1', 'ni2''.");
     }
 
     if(format == 'auto') {
@@ -141,7 +186,13 @@ read.fs.morph <- function(filepath, format='auto') {
     } else if(format == "gii") {
         data = read.fs.morph.gii(filepath);
     } else if(format == "smp") {
-      data = read.fs.morph.bvsmp(filepath);
+        data = read.fs.morph.bvsmp(filepath);
+    } else if (format == 'nii' | (format == 'auto' & filepath.ends.with(filepath, c('.nii', '.nii.gz')))) {
+        data = read.fs.morph.nii(filepath);
+    } else if(format == 'ni1') {
+        data = read.fs.morph.ni1(filepath);
+    } else if(format == 'ni2') {
+        data = read.fs.morph.ni2(filepath);
     } else {
         data = read.fs.curv(filepath);
     }
